@@ -1,7 +1,7 @@
 
 /*
- *  $Id: autoopts.c,v 4.14 2006/03/25 19:24:56 bkorb Exp $
- *  Time-stamp:      "2005-10-29 13:19:36 bkorb"
+ *  $Id: autoopts.c,v 4.16 2006/09/24 02:11:15 bkorb Exp $
+ *  Time-stamp:      "2006-09-22 18:21:53 bkorb"
  *
  *  This file contains all of the routines that must be linked into
  *  an executable to use the generated option processing.  The optional
@@ -56,17 +56,19 @@
 #  include "compat/pathfind.c"
 #endif
 
-#ifndef HAVE_LIBSNPRINTFV
-# ifndef HAVE_SNPRINTF
-#   include "compat/snprintf.c"
-# endif
-
-# ifndef HAVE_STRDUP
-#   include "compat/strdup.c"
-# endif
+#ifndef HAVE_SNPRINTF
+#  include "compat/snprintf.c"
 #endif
 
-static const char zNil[] = "";
+#ifndef HAVE_STRDUP
+#  include "compat/strdup.c"
+#endif
+
+#ifndef HAVE_STRCHR
+#  include "compat/strchr.c"
+#endif
+
+static char const zNil[] = "";
 
 #define SKIP_RC_FILES(po) \
     DISABLED_OPT(&((po)->pOptDesc[ (po)->specOptIdx.save_opts+1]))
@@ -86,6 +88,50 @@ static int
 checkConsistency( tOptions* pOpts );
 /* = = = END-STATIC-FORWARD = = = */
 
+LOCAL void *
+ao_malloc( size_t sz )
+{
+    void * res = malloc(sz);
+    if (res == NULL) {
+        fprintf( stderr, "malloc of %d bytes failed\n", sz );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
+
+LOCAL void *
+ao_realloc( void *p, size_t sz )
+{
+    void * res = realloc(p, sz);
+    if (res == NULL) {
+        fprintf( stderr, "realloc of %d bytes at 0x%p failed\n", sz, p );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
+
+LOCAL void
+ao_free( void *p )
+{
+    if (p != NULL)
+        free(p);
+}
+
+
+LOCAL char *
+ao_strdup( char const *str )
+{
+    char * res = strdup(str);
+    if (res == NULL) {
+        fprintf( stderr, "strdup of %d byte string failed\n", strlen(str) );
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
+
 /*
  *  handleOption
  *
@@ -102,7 +148,7 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
     tOptDesc* pOD = pOptState->pOD;
     tOptProc* pOP = pOD->pOptProc;
 
-    pOD->pzLastArg =  pOptState->pzOptArg;
+    pOD->optArg.argString = pOptState->pzOptArg;
 
     /*
      *  IF we are presetting options, then we will ignore any un-presettable
@@ -167,7 +213,7 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
          *  Copy the most recent option argument.  set membership state
          *  is kept in ``p->optCookie''.  Do not overwrite.
          */
-        p->pzLastArg = pOD->pzLastArg;
+        p->optArg.argString = pOD->optArg.argString;
         pOD = p;
 
     } else {
@@ -184,11 +230,11 @@ handleOption( tOptions* pOpts, tOptState* pOptState )
      */
     if (  (pOD->fOptState & OPTST_DEFINED)
        && (++pOD->optOccCt > pOD->optMaxCt)  )  {
-        const char* pzEqv =
+        char const* pzEqv =
             (pOD->optEquivIndex != NO_EQUIVALENT) ? zEquiv : zNil;
 
         if ((pOpts->fOptSet & OPTPROC_ERRSTOP) != 0) {
-            const char* pzFmt = (pOD->optMaxCt > 1) ? zAtMost : zOnlyOne;
+            char const* pzFmt = (pOD->optMaxCt > 1) ? zAtMost : zOnlyOne;
             fputs( zErrOnly, stderr );
             fprintf( stderr, pzFmt, pOD->pz_Name, pzEqv,
                      pOD->optMaxCt );
@@ -350,7 +396,7 @@ longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState )
  *  Find the short option descriptor for the current option
  */
 LOCAL tSuccess
-shortOptionFind( tOptions* pOpts, tAoUC optValue, tOptState* pOptState )
+shortOptionFind( tOptions* pOpts, uint_t optValue, tOptState* pOptState )
 {
     tOptDesc*  pRes = pOpts->pOptDesc;
     int        ct   = pOpts->optCt;
@@ -423,7 +469,7 @@ findOptDesc( tOptions* pOpts, tOptState* pOptState )
      *  OTHERWISE see if there is room to advance and then do so.
      */
     if ((pOpts->pzCurOpt != NULL) && (*pOpts->pzCurOpt != NUL))
-        return shortOptionFind( pOpts, *pOpts->pzCurOpt, pOptState );
+        return shortOptionFind( pOpts, (tAoUC)*(pOpts->pzCurOpt), pOptState );
 
     if (pOpts->curOptIdx >= pOpts->origArgCt)
         return PROBLEM; /* NORMAL COMPLETION */
@@ -493,7 +539,7 @@ findOptDesc( tOptions* pOpts, tOptState* pOptState )
      *  short (i.e. single character) option.
      */
     if ((pOpts->fOptSet & OPTPROC_SHORTOPT) != 0)
-        return shortOptionFind( pOpts, *pOpts->pzCurOpt, pOptState );
+        return shortOptionFind( pOpts, (tAoUC)*(pOpts->pzCurOpt), pOptState );
 
     return longOptionFind( pOpts, pOpts->pzCurOpt, pOptState );
 }
@@ -1037,7 +1083,6 @@ optionProcess(
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/autoopts.c */
